@@ -31,12 +31,12 @@ class px100(ERobot):
     """
     def __init__(self):
 
-        args = super().urdf_to_ets_args(
+        links, name = self.URDF_read(
             "interbotix_descriptions/urdf/px100.urdf.xacro")
 
         super().__init__(
-                args[0],
-                name=args[1],
+                links,
+                name=name,
                 manufacturer='Interbotix'
             )
 
@@ -49,4 +49,5 @@ class px100(ERobot):
 if __name__ == '__main__':   # pragma nocover
 
     robot = px100()
-    print(robot.links[0].mesh)
+    print(robot)
+    robot.dynamics()
